# Active Backlog

This page lists the backlog from oplog owners.
If you have a feature request, please open an issue, as described in [Contribution](contribution.md).

## Code
- [ ] Revisit the timing mechanism (performance timer vs clock timer)
- [ ] Support custom inheritors
- [x] CLI usage: progress bars
- [ ] CLI usage: spinner

## DevOps (prioritized)

- [x] CI/CD (Github Actions) with all checks
- [x] Justfile
- [ ] doc strings to Mkdocs: https://github.com/mkdocstrings/mkdocstrings
- [ ] doc string enforcement
- [ ] Poetry
- [ ] Precommit Hooks
- [ ] Check push policy vs PR policy
- [ ] Docker
- [ ] Dev Container
- [ ] Coverage % in badge (currently shows pass/fail)
- [ ] Individual coverage in justfile
- [ ] Consider more quality checkers (or config for existing one)
- [ ] Consider more linters (or config for existing one)
